pygeodesy.internals

Package pygeodesy :: Module internals |
[frames] | no frames]

# Module internals

Mostly INTERNAL functions, except machine, print_ and printf.

Version: 26.01.13

Functions
typename(obj, *dflt) Get the `obj.__name__`, the `dflt` or its outer `type.__name__` or `NN` (`str`). |
machine() Return standard `platform.machine`, but distinguishing Intel native from Intel emulation on Apple Silicon (on macOS only). |
print_(*args, **nl_nt_prec_prefix__end_file_flush_sep__kwds) Python 3+ `print`-like formatting and printing. |
printf(fmt, *args, **nl_nt_prec_prefix__end_file_flush_sep__kwds) `Printf-style` and Python 3+ `print`-like formatting and printing. |

Function Details

### machine() |
Return standard `platform.machine`, but distinguishing Intel native from Intel emulation on Apple Silicon (on macOS only). Returns: Machine `'arm64'` for Apple Silicon native, `'x86_64'` for Intel native, `"arm64_x86_64"` for Intel emulation, etc. (`str` with `comma`s replaced by `underscore`s).

### print_ (*args, **nl_nt_prec_prefix__end_file_flush_sep__kwds) |
Python 3+ `print`-like formatting and printing. Arguments: `args` - Values to be converted to `str` and joined by `sep`, all positional. See Also: Function printf for further details.

### printf (fmt, *args, **nl_nt_prec_prefix__end_file_flush_sep__kwds) |
`Printf-style` and Python 3+ `print`-like formatting and printing. Arguments: `fmt` - Printf-style format specification (`str`). `args` - Arguments to be formatted (any `type`, all positional). `nl_nt_prec_prefix__end_file_flush_sep__kwds` - Optional keyword arguments `nl=0` for the number of leading blank lines (`int`), `nt=0` the number of trailing blank lines (`int`), `prefix=NN` to be inserted before the formatted text (`str`) and Python 3+ `print` keyword arguments `end`, `sep`, `file` and `flush`. Any remaining `kwds` are `printf-style` name-value pairs to be formatted, iff no `args` are present using `prec=6` for the number of decimal digits (`int`). Returns: Number of bytes written.